==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/FirewallPolicyFilterRuleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.FirewallPolicyFilterRuleArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Any
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Firewall Policy Filter Rule.
 * @property action The action type of a Filter rule.
 * @property name The name of the rule.
 * @property priority Priority of the Firewall Policy Rule resource.
 * @property ruleConditions Collection of rule conditions used by a rule.
 * @property ruleType The type of the rule.
 * Expected value is 'FirewallPolicyFilterRule'.
 */
public data class FirewallPolicyFilterRuleArgs(
    public val action: Output<FirewallPolicyFilterRuleActionArgs>? = null,
    public val name: Output<String>? = null,
    public val priority: Output<Int>? = null,
    public val ruleConditions: Output<List<Any>>? = null,
    public val ruleType: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.FirewallPolicyFilterRuleArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.FirewallPolicyFilterRuleArgs =
        com.pulumi.azurenative.network.inputs.FirewallPolicyFilterRuleArgs.builder()
            .action(action?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .name(name?.applyValue({ args0 -> args0 }))
            .priority(priority?.applyValue({ args0 -> args0 }))
            .ruleConditions(ruleConditions?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .ruleType(ruleType.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [FirewallPolicyFilterRuleArgs].
 */
@PulumiTagMarker
public class FirewallPolicyFilterRuleArgsBuilder internal constructor() {
    private var action: Output<FirewallPolicyFilterRuleActionArgs>? = null

    private var name: Output<String>? = null

    private var priority: Output<Int>? = null

    private var ruleConditions: Output<List<Any>>? = null

    private var ruleType: Output<String>? = null

    /**
     * @param value The action type of a Filter rule.
     */
    @JvmName("gpeihwurpkjjtgfa")
    public suspend fun action(`value`: Output<FirewallPolicyFilterRuleActionArgs>) {
        this.action = value
    }

    /**
     * @param value The name of the rule.
     */
    @JvmName("ymelmurpeevoqnlo")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Priority of the Firewall Policy Rule resource.
     */
    @JvmName("erlmcydobigyvwms")
    public suspend fun priority(`value`: Output<Int>) {
        this.priority = value
    }

    /**
     * @param value Collection of rule conditions used by a rule.
     */
    @JvmName("ybgsnlvplofxkgdh")
    public suspend fun ruleConditions(`value`: Output<List<Any>>) {
        this.ruleConditions = value
    }

    @JvmName("wvlogiwjgnomfxci")
    public suspend fun ruleConditions(vararg values: Output<Any>) {
        this.ruleConditions = Output.all(values.asList())
    }

    /**
     * @param values Collection of rule conditions used by a rule.
     */
    @JvmName("gldxvmpupsunollb")
    public suspend fun ruleConditions(values: List<Output<Any>>) {
        this.ruleConditions = Output.all(values)
    }

    /**
     * @param value The type of the rule.
     * Expected value is 'FirewallPolicyFilterRule'.
     */
    @JvmName("tpfknfmgjbwpsvta")
    public suspend fun ruleType(`value`: Output<String>) {
        this.ruleType = value
    }

    /**
     * @param value The action type of a Filter rule.
     */
    @JvmName("hielgyflssjcticn")
    public suspend fun action(`value`: FirewallPolicyFilterRuleActionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param argument The action type of a Filter rule.
     */
    @JvmName("hkrrkffhsaqdfueh")
    public suspend
    fun action(argument: suspend FirewallPolicyFilterRuleActionArgsBuilder.() -> Unit) {
        val toBeMapped = FirewallPolicyFilterRuleActionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.action = mapped
    }

    /**
     * @param value The name of the rule.
     */
    @JvmName("seoxpaiaaimcriyy")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Priority of the Firewall Policy Rule resource.
     */
    @JvmName("xwrfjilvoplpapkp")
    public suspend fun priority(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.priority = mapped
    }

    /**
     * @param value Collection of rule conditions used by a rule.
     */
    @JvmName("yryduupakxlygkav")
    public suspend fun ruleConditions(`value`: List<Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ruleConditions = mapped
    }

    /**
     * @param values Collection of rule conditions used by a rule.
     */
    @JvmName("isnravgrqqnuoqft")
    public suspend fun ruleConditions(vararg values: Any) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ruleConditions = mapped
    }

    /**
     * @param value The type of the rule.
     * Expected value is 'FirewallPolicyFilterRule'.
     */
    @JvmName("ajvypdrjajbsdyhh")
    public suspend fun ruleType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ruleType = mapped
    }

    internal fun build(): FirewallPolicyFilterRuleArgs = FirewallPolicyFilterRuleArgs(
        action = action,
        name = name,
        priority = priority,
        ruleConditions = ruleConditions,
        ruleType = ruleType ?: throw PulumiNullFieldException("ruleType"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/FirewallPolicyFilterRuleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.FirewallPolicyFilterRuleArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Any
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Firewall Policy Filter Rule.
 * @property action The action type of a Filter rule.
 * @property name The name of the rule.
 * @property priority Priority of the Firewall Policy Rule resource.
 * @property ruleConditions Collection of rule conditions used by a rule.
 * @property ruleType The type of the rule.
 * Expected value is 'FirewallPolicyFilterRule'.
 */
public data class FirewallPolicyFilterRuleArgs(
    public val action: Output<FirewallPolicyFilterRuleActionArgs>? = null,
    public val name: Output<String>? = null,
    public val priority: Output<Int>? = null,
    public val ruleConditions: Output<List<Any>>? = null,
    public val ruleType: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.FirewallPolicyFilterRuleArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.FirewallPolicyFilterRuleArgs =
        com.pulumi.azurenative.network.inputs.FirewallPolicyFilterRuleArgs.builder()
            .action(action?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .name(name?.applyValue({ args0 -> args0 }))
            .priority(priority?.applyValue({ args0 -> args0 }))
            .ruleConditions(ruleConditions?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .ruleType(ruleType.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [FirewallPolicyFilterRuleArgs].
 */
@PulumiTagMarker
public class FirewallPolicyFilterRuleArgsBuilder internal constructor() {
    private var action: Output<FirewallPolicyFilterRuleActionArgs>? = null

    private var name: Output<String>? = null

    private var priority: Output<Int>? = null

    private var ruleConditions: Output<List<Any>>? = null

    private var ruleType: Output<String>? = null

    /**
     * @param value The action type of a Filter rule.
     */
    @JvmName("huudpwoaxsmkefbw")
    public suspend fun action(`value`: Output<FirewallPolicyFilterRuleActionArgs>) {
        this.action = value
    }

    /**
     * @param value The name of the rule.
     */
    @JvmName("tnpaffafnpvwdjcw")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Priority of the Firewall Policy Rule resource.
     */
    @JvmName("aucwswayroadnfwc")
    public suspend fun priority(`value`: Output<Int>) {
        this.priority = value
    }

    /**
     * @param value Collection of rule conditions used by a rule.
     */
    @JvmName("dmcxqllogkmroiwy")
    public suspend fun ruleConditions(`value`: Output<List<Any>>) {
        this.ruleConditions = value
    }

    @JvmName("drqflfbjxsflfxce")
    public suspend fun ruleConditions(vararg values: Output<Any>) {
        this.ruleConditions = Output.all(values.asList())
    }

    /**
     * @param values Collection of rule conditions used by a rule.
     */
    @JvmName("gygjcjtpqlegonin")
    public suspend fun ruleConditions(values: List<Output<Any>>) {
        this.ruleConditions = Output.all(values)
    }

    /**
     * @param value The type of the rule.
     * Expected value is 'FirewallPolicyFilterRule'.
     */
    @JvmName("soqxxkuiexeeigfa")
    public suspend fun ruleType(`value`: Output<String>) {
        this.ruleType = value
    }

    /**
     * @param value The action type of a Filter rule.
     */
    @JvmName("jnjtuuasgldugcwa")
    public suspend fun action(`value`: FirewallPolicyFilterRuleActionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param argument The action type of a Filter rule.
     */
    @JvmName("xhamunufhbfdyxec")
    public suspend
    fun action(argument: suspend FirewallPolicyFilterRuleActionArgsBuilder.() -> Unit) {
        val toBeMapped = FirewallPolicyFilterRuleActionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.action = mapped
    }

    /**
     * @param value The name of the rule.
     */
    @JvmName("svsehbenkabkyiqm")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Priority of the Firewall Policy Rule resource.
     */
    @JvmName("qvtxrfbkohlfjihf")
    public suspend fun priority(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.priority = mapped
    }

    /**
     * @param value Collection of rule conditions used by a rule.
     */
    @JvmName("igteyxyrglianloq")
    public suspend fun ruleConditions(`value`: List<Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ruleConditions = mapped
    }

    /**
     * @param values Collection of rule conditions used by a rule.
     */
    @JvmName("tyilkwpnorvaqtgu")
    public suspend fun ruleConditions(vararg values: Any) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ruleConditions = mapped
    }

    /**
     * @param value The type of the rule.
     * Expected value is 'FirewallPolicyFilterRule'.
     */
    @JvmName("vmirchsrtnexbtid")
    public suspend fun ruleType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ruleType = mapped
    }

    internal fun build(): FirewallPolicyFilterRuleArgs = FirewallPolicyFilterRuleArgs(
        action = action,
        name = name,
        priority = priority,
        ruleConditions = ruleConditions,
        ruleType = ruleType ?: throw PulumiNullFieldException("ruleType"),
    )
}
